/*----------------------

   GATE - Geant4 Application for Tomographic Emission 
   OpenGATE Collaboration 
     
   Corinne Groiselle <corinne.groiselle@umassmed.edu>
   
   Copyright (C) 2003 UMASS/Division of Nuclear Medicine, Worcester, MA 01655, USA

This software is distributed under the terms 
of the GNU Lesser General  Public Licence (LGPL) 
See GATE/LICENSE.txt for further details 
----------------------*/

/*!

  \file GateParallelepipedCreatorMessenger.cc
  
  $Log: GateParallelepipedCreatorMessenger.cc,v $
  Revision 1.1  2003/09/25 13:07:59  sjan
  Definition of a Parallelepiped volume : C.Groiselle


  Revision 

  \brief Class GateParallelepipedCreatorMessenger
  \brief By Corinne.Groiselle@umassmed.edu
  \brief $Id: GateParallelepipedCreatorMessenger.cc,v 1.1 2003/09/25 13:07:59 sjan Exp $
*/

#include "GateParallelepipedCreatorMessenger.hh"

#include "G4UIdirectory.hh"
#include "G4UIcmdWithAString.hh"
#include "G4UIcmdWithAnInteger.hh"
#include "G4UIcmdWithADoubleAndUnit.hh"
#include "G4UIcmdWith3VectorAndUnit.hh"
#include "G4UIcmdWithoutParameter.hh"

#include "GateParallelepipedCreator.hh"

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

GateParallelepipedCreatorMessenger::GateParallelepipedCreatorMessenger(GateParallelepipedCreator *itsCreator)
  :GateObjectCreatorMessenger(itsCreator)
{ 
  G4String cmdName = GetDirectoryName()+"setDx";
  ParallelepipedDxCmd = new G4UIcmdWithADoubleAndUnit(cmdName.c_str(),this);
  ParallelepipedDxCmd->SetGuidance("Set Dx dimension of the Parallelepiped.");
  ParallelepipedDxCmd->SetParameterName("Dx",false);
  ParallelepipedDxCmd->SetRange("Dx>=0.");
  ParallelepipedDxCmd->SetUnitCategory("Length");

  cmdName = GetDirectoryName()+"setDy";
  ParallelepipedDyCmd = new G4UIcmdWithADoubleAndUnit(cmdName.c_str(),this);
  ParallelepipedDyCmd->SetGuidance("Set Dy dimension of the Parallelepiped.");
  ParallelepipedDyCmd->SetParameterName("Dy",false);
  ParallelepipedDyCmd->SetRange("Dy>=0.");
  ParallelepipedDyCmd->SetUnitCategory("Length");

  cmdName = GetDirectoryName()+"setDz";
  ParallelepipedDzCmd = new G4UIcmdWithADoubleAndUnit(cmdName.c_str(),this);
  ParallelepipedDzCmd->SetGuidance("Set Dz dimension of the Parallelepiped.");
  ParallelepipedDzCmd->SetParameterName("Dz",false);
  ParallelepipedDzCmd->SetRange("Dz>=0.");
  ParallelepipedDzCmd->SetUnitCategory("Length");

  cmdName = GetDirectoryName()+"setAlpha";
  ParallelepipedAlphaCmd = new G4UIcmdWithADoubleAndUnit(cmdName.c_str(),this);
  ParallelepipedAlphaCmd->SetGuidance("Set Alpha angle.");
  ParallelepipedAlphaCmd->SetParameterName("Alpha",false);
  ParallelepipedAlphaCmd->SetUnitCategory("Angle");

  cmdName = GetDirectoryName()+"setTheta";
  ParallelepipedThetaCmd = new G4UIcmdWithADoubleAndUnit(cmdName.c_str(),this);
  ParallelepipedThetaCmd->SetGuidance("Set Theta angle.");
  ParallelepipedThetaCmd->SetParameterName("Theta",false);
  ParallelepipedThetaCmd->SetUnitCategory("Angle");

  cmdName = GetDirectoryName()+"setPhi";
  ParallelepipedPhiCmd = new G4UIcmdWithADoubleAndUnit(cmdName.c_str(),this);
  ParallelepipedPhiCmd->SetGuidance("Set Phi angle.");
  ParallelepipedPhiCmd->SetParameterName("Phi",false);
  ParallelepipedPhiCmd->SetUnitCategory("Angle");
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

GateParallelepipedCreatorMessenger::~GateParallelepipedCreatorMessenger()
{
    delete ParallelepipedDxCmd;
    delete ParallelepipedDyCmd;
    delete ParallelepipedDzCmd;
    delete ParallelepipedAlphaCmd;
    delete ParallelepipedThetaCmd;
    delete ParallelepipedPhiCmd;
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

void GateParallelepipedCreatorMessenger::SetNewValue(G4UIcommand* command,G4String newValue)
{ 
  if( command == ParallelepipedDxCmd )
    { GetParallelepipedCreator()->SetParallelepipedDx(ParallelepipedDxCmd->GetNewDoubleValue(newValue));TellGeometryToRebuild();}
  else if( command == ParallelepipedDyCmd )
    { GetParallelepipedCreator()->SetParallelepipedDy(ParallelepipedDyCmd->GetNewDoubleValue(newValue));TellGeometryToRebuild();}
  else if( command==ParallelepipedDzCmd )
    { GetParallelepipedCreator()->SetParallelepipedDz(ParallelepipedDzCmd->GetNewDoubleValue(newValue)); TellGeometryToRebuild();}   
  else if( command == ParallelepipedAlphaCmd )
    { GetParallelepipedCreator()->SetParallelepipedAlpha(ParallelepipedAlphaCmd->GetNewDoubleValue(newValue));TellGeometryToRebuild();}
  else if( command == ParallelepipedThetaCmd )
    { GetParallelepipedCreator()->SetParallelepipedTheta(ParallelepipedThetaCmd->GetNewDoubleValue(newValue));TellGeometryToRebuild();}
  else if( command == ParallelepipedPhiCmd )
    { GetParallelepipedCreator()->SetParallelepipedPhi(ParallelepipedPhiCmd->GetNewDoubleValue(newValue));TellGeometryToRebuild();}
  else
    GateObjectCreatorMessenger::SetNewValue(command,newValue);
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
